@@ -1,11 +1,19 @@
-"""jc - JSON CLI output utility airport -I Parser
+"""jc - JSON CLI output utility `airport -I` command output parser
 
-Usage:
+The `airport` program can be found at `/System/Library/PrivateFrameworks/Apple80211.framework/Versions/Current/Resources/airport`.
 
-    specify --airport as the first argument if the piped input is coming from airport -I (OSX)
+Usage (cli):
 
-    This program can be found at:
-    /System/Library/PrivateFrameworks/Apple80211.framework/Versions/Current/Resources/airport
+    $ airport -I | jc --airport
+
+    or
+
+    $ jc airport -I
+
+Usage (module):
+
+    import jc.parsers.airport
+    result = jc.parsers.airport.parse(airport_command_output)
 
 Compatibility:
 
