@@ -1,11 +1,19 @@
-"""jc - JSON CLI output utility airport -s Parser
+"""jc - JSON CLI output utility `airport -s` command output parser
 
-Usage:
+The `airport` program can be found at `/System/Library/PrivateFrameworks/Apple80211.framework/Versions/Current/Resources/airport`.
 
-    specify --airport as the first argument if the piped input is coming from airport -s (OSX)
+Usage (cli):
 
-    This program can be found at:
-    /System/Library/PrivateFrameworks/Apple80211.framework/Versions/Current/Resources/airport
+    $ airport -s | jc --airport-s
+
+    or
+
+    $ jc airport -s
+
+Usage (module):
+
+    import jc.parsers.airport_s
+    result = jc.parsers.airport_s.parse(airport_s_command_output)
 
 Compatibility:
 
