@@ -1,8 +1,19 @@
-"""jc - JSON CLI output utility crontab command and file Parser
+"""jc - JSON CLI output utility `crontab -l` command output and crontab file parser
 
-Usage:
+Supports `crontab -l` command output and crontab files.
 
-    specify --crontab as the first argument if the piped input is coming from crontab -l or a crontab file
+Usage (cli):
+
+    $ crontab -l | jc --crontab
+
+    or
+
+    $ jc crontab -l
+
+Usage (module):
+
+    import jc.parsers.crontab
+    result = jc.parsers.crontab.parse(crontab_output)
 
 Compatibility:
 
