@@ -1,8 +1,15 @@
-"""jc - JSON CLI output utility crontab file Parser
+"""jc - JSON CLI output utility `crontab -l` command output and crontab file parser
 
-Usage:
+This version of the `crontab -l` parser supports output that contains user information for processes.
 
-    specify --crontab-u as the first argument if the piped input is coming from a crontab file with User specified
+Usage (cli):
+
+    $ crontab -l | jc --crontab-u
+
+Usage (module):
+
+    import jc.parsers.crontab_u
+    result = jc.parsers.crontab_u.parse(crontab_u_output)
 
 Compatibility:
 
