@@ -1,11 +1,15 @@
-"""jc - JSON CLI output utility csv Parser
+"""jc - JSON CLI output utility `csv` file parser
 
-Usage:
+The `csv` parser will attempt to automatically detect the delimiter character. If the delimiter cannot be detected it will default to comma. The first row of the file must be a header row.
 
-    specify --csv as the first argument if the piped input is coming from a csv file.
-    the csv parser will attempt to automatically detect the delimiter character.
-    if the delimiter cannot be detected it will default to comma.
-    the first row of the file must be a header row.
+Usage (cli):
+
+    $ cat file.csv | jc --csv
+
+Usage (module):
+
+    import jc.parsers.csv
+    result = jc.parsers.csv.parse(csv_output)
 
 Compatibility:
 
