@@ -1,8 +1,17 @@
-"""jc - JSON CLI output utility df Parser
+"""jc - JSON CLI output utility `df` command output parser
 
-Usage:
+Usage (cli):
 
-    specify --df as the first argument if the piped input is coming from df
+    $ df | jc --df
+
+    or
+
+    $ jc df
+
+Usage (module):
+
+    import jc.parsers.df
+    result = jc.parsers.df.parse(df_command_output)
 
 Compatibility:
 
