@@ -1,8 +1,17 @@
-"""jc - JSON CLI output utility dig Parser
+"""jc - JSON CLI output utility `dig` command output parser
 
-Usage:
+Usage (cli):
 
-    Specify --dig as the first argument if the piped input is coming from dig
+    $ dig example.com | jc --dig
+
+    or
+
+    $ jc dig example.com
+
+Usage (module):
+
+    import jc.parsers.dig
+    result = jc.parsers.dig.parse(dig_command_output)
 
 Compatibility:
 
