@@ -1,8 +1,17 @@
-"""jc - JSON CLI output utility dmidecode Parser
+"""jc - JSON CLI output utility `dmidecode` command output parser
 
-Usage:
+Usage (cli):
 
-    specify --dmidecode as the first argument if the piped input is coming from dmidecode
+    $ dmidecode | jc --dmidecode
+
+    or
+
+    $ jc dmidecode
+
+Usage (module):
+
+    import jc.parsers.dmidecode
+    result = jc.parsers.dmidecode.parse(dmidecode_command_output)
 
 Compatibility:
 
