@@ -1,8 +1,17 @@
-"""jc - JSON CLI output utility du Parser
+"""jc - JSON CLI output utility `du` command output parser
 
-Usage:
+Usage (cli):
 
-    specify --du as the first argument if the piped input is coming from du
+    $ du | jc --du
+
+    or
+
+    $ jc du
+
+Usage (module):
+
+    import jc.parsers.du
+    result = jc.parsers.du.parse(du_command_output)
 
 Compatibility:
 
