@@ -1,8 +1,19 @@
-"""jc - JSON CLI output utility env Parser
+"""jc - JSON CLI output utility `env` and `printenv` command output parser
 
-Usage:
+This parser will output a list of dictionaries each containing `name` and `value` keys. If you would like a simple dictionary output, then use the `-r` command-line option or the `raw=True` argument in the `parse()` function.
 
-    specify --env as the first argument if the piped input is coming from env
+Usage (cli):
+
+    $ env | jc --env
+
+    or
+
+    $ jc env
+
+Usage (module):
+
+    import jc.parsers.env
+    result = jc.parsers.env.parse(env_command_output)
 
 Compatibility:
 
@@ -59,7 +70,7 @@ class info():
 
     # compatible options: linux, darwin, cygwin, win32, aix, freebsd
     compatible = ['linux', 'darwin', 'cygwin', 'win32', 'aix', 'freebsd']
-    magic_commands = ['env']
+    magic_commands = ['env', 'printenv']
 
 
 __version__ = info.version
