@@ -1,8 +1,17 @@
-"""jc - JSON CLI output utility file command Parser
+"""jc - JSON CLI output utility `file` command output parser
 
-Usage:
+Usage (cli):
 
-    specify --file as the first argument if the piped input is coming from file.
+    $ file * | jc --file
+
+    or
+
+    $ jc file *
+
+Usage (module):
+
+    import jc.parsers.file
+    result = jc.parsers.file.parse(file_command_output)
 
 Compatibility:
 
