@@ -1,8 +1,19 @@
-"""jc - JSON CLI output utility foo Parser
+"""jc - JSON CLI output utility `foo` command output parser
 
-Usage:
+<<Short foo description and caveats>>
 
-    specify --foo as the first argument if the piped input is coming from foo
+Usage (cli):
+
+    $ foo | jc --foo
+
+    or
+
+    $ jc foo
+
+Usage (module):
+
+    import jc.parsers.foo
+    result = jc.parsers.foo.parse(foo_command_output)
 
 Compatibility:
 
