@@ -1,8 +1,17 @@
-"""jc - JSON CLI output utility free Parser
+"""jc - JSON CLI output utility `free` command output parser
 
-Usage:
+Usage (cli):
 
-    specify --free as the first argument if the piped input is coming from free
+    $ free | jc --free
+
+    or
+
+    $ jc free
+
+Usage (module):
+
+    import jc.parsers.free
+    result = jc.parsers.free.parse(free_command_output)
 
 Compatibility:
 
