@@ -1,8 +1,13 @@
-"""jc - JSON CLI output utility /etc/group file Parser
+"""jc - JSON CLI output utility `/etc/group` file parser
 
-Usage:
+Usage (cli):
 
-    specify --group as the first argument if the piped input is coming from /etc/group
+    $ cat /etc/group | jc --group
+
+Usage (module):
+
+    import jc.parsers.group
+    result = jc.parsers.group.parse(group_file_output)
 
 Compatibility:
 
