@@ -1,8 +1,15 @@
-"""jc - JSON CLI output utility history Parser
+"""jc - JSON CLI output utility `history` command output parser
 
-Usage:
+This parser will output a list of dictionaries each containing `line` and `command` keys. If you would like a simple dictionary output, then use the `-r` command-line option or the `raw=True` argument in the `parse()` function.
 
-    specify --history as the first argument if the piped input is coming from history
+Usage (cli):
+
+    $ history | jc --history
+
+Usage (module):
+
+    import jc.parsers.history
+    result = jc.parsers.history.parse(history_command_output)
 
 Compatibility:
 
