@@ -1,8 +1,17 @@
-"""jc - JSON CLI output utility id Parser
+"""jc - JSON CLI output utility `id` command output parser
 
-Usage:
+Usage (cli):
 
-    specify --id as the first argument if the piped input is coming from id
+    $ id | jc --id
+
+    or
+
+    $ jc id
+
+Usage (module):
+
+    import jc.parsers.id
+    result = jc.parsers.id.parse(id_command_output)
 
 Compatibility:
 
