@@ -1,10 +1,19 @@
-"""jc - JSON CLI output utility ifconfig Parser
+"""jc - JSON CLI output utility `ifconfig` command output parser
 
-Usage:
+Note: No `ifconfig` options are supported.
 
-    specify --ifconfig as the first argument if the piped input is coming from ifconfig
+Usage (cli):
 
-    no ifconfig options are supported.
+    $ ifconfig | jc --ifconfig
+
+    or
+
+    $ jc ifconfig
+
+Usage (module):
+
+    import jc.parsers.ifconfig
+    result = jc.parsers.ifconfig.parse(ifconfig_command_output)
 
 Compatibility:
 
