@@ -1,10 +1,19 @@
-"""jc - JSON CLI output utility ipables Parser
+"""jc - JSON CLI output utility `ipables` command output parser
 
-Usage:
+Supports `-vLn` and `--line-numbers` for all tables.
 
-    Specify --iptables as the first argument if the piped input is coming from iptables
+Usage (cli):
 
-    Supports -vLn and --line-numbers for all tables
+    $ sudo iptables -L -t nat | jc --iptables
+
+    or
+
+    $ jc iptables -L -t nat
+
+Usage (module):
+
+    import jc.parsers.iptables
+    result = jc.parsers.iptables.parse(iptables_command_output)
 
 Compatibility:
 
