@@ -1,10 +1,19 @@
-"""jc - JSON CLI output utility jobs Parser
+"""jc - JSON CLI output utility `jobs` command output parser
 
-Usage:
+Also supports the `-l` option.
 
-    specify --jobs as the first argument if the piped input is coming from jobs
+Usage (cli):
 
-    Also supports the -l option
+    $ jobs | jc --jobs
+
+    or
+
+    $ jc jobs
+
+Usage (module):
+
+    import jc.parsers.jobs
+    result = jc.parsers.jobs.parse(jobs_command_output)
 
 Compatibility:
 
