@@ -1,20 +1,24 @@
-"""jc - JSON CLI output utility ls Parser
+"""jc - JSON CLI output utility `ls` and `vdir` command output parser
 
-Note: The -l or -b option of ls should be used to correctly parse filenames that include newline characters.
-      Since ls does not encode newlines in filenames when outputting to a pipe it will cause jc to see
-      multiple files instead of a single file if -l or -b is not used.
+Options supported:
+- `lbaR`
+- `--time-style=full-iso`
+- `-h`: File sizes will be available in text form with `-r` but larger file sizes with human readable suffixes will be converted to `Null` in the default view since the parser attempts to convert this field to an integer.
 
-Usage:
+Note: The `-l` or `-b` option of `ls` should be used to correctly parse filenames that include newline characters. Since `ls` does not encode newlines in filenames when outputting to a pipe it will cause `jc` to see multiple files instead of a single file if `-l` or `-b` is not used. Alternatively, `vdir` can be used, which is the same as running `ls -lb`.
 
-    specify --ls as the first argument if the piped input is coming from ls
+Usage (cli):
 
-    ls options supported:
+    $ ls | jc --ls
 
-                    -lbaR
-    --time-style=full-iso
-                       -h  file sizes will be available in text form with -r but larger file sizes
-                               with human readable suffixes will be converted to Null in default view
-                               since the parser attempts to convert this field to an integer.
+    or
+
+    $ jc ls
+
+Usage (module):
+
+    import jc.parsers.ls
+    result = jc.parsers.ls.parse(ls_command_output)
 
 Compatibility:
 
@@ -156,7 +160,7 @@ class info():
 
     # compatible options: linux, darwin, cygwin, win32, aix, freebsd
     compatible = ['linux', 'darwin', 'cygwin', 'aix', 'freebsd']
-    magic_commands = ['ls']
+    magic_commands = ['ls', 'vdir']
 
 
 __version__ = info.version
