@@ -1,8 +1,17 @@
-"""jc - JSON CLI output utility lsblk Parser
+"""jc - JSON CLI output utility `lsblk` command output parser
 
-Usage:
+Usage (cli):
 
-    specify --lsblk as the first argument if the piped input is coming from lsblk
+    $ lsblk | jc --lsblk
+
+    or
+
+    $ jc lsblk
+
+Usage (module):
+
+    import jc.parsers.lsblk
+    result = jc.parsers.lsblk.parse(lsblk_command_output)
 
 Compatibility:
 
