@@ -1,8 +1,17 @@
-"""jc - JSON CLI output utility lsmod Parser
+"""jc - JSON CLI output utility `lsmod` command output parser
 
-Usage:
+Usage (cli):
 
-    specify --lsmod as the first argument if the piped input is coming from lsmod
+    $ lsmod | jc --lsmod
+
+    or
+
+    $ jc lsmod
+
+Usage (module):
+
+    import jc.parsers.lsmod
+    result = jc.parsers.lsmod.parse(lsmod_command_output)
 
 Compatibility:
 
