@@ -1,8 +1,17 @@
-"""jc - JSON CLI output utility mount Parser
+"""jc - JSON CLI output utility `mount` command output parser
 
-Usage:
+Usage (cli):
 
-    specify --mount as the first argument if the piped input is coming from mount
+    $ mount | jc --mount
+
+    or
+
+    $ jc mount
+
+Usage (module):
+
+    import jc.parsers.mount
+    result = jc.parsers.mount.parse(mount_command_output)
 
 Compatibility:
 
