@@ -1,10 +1,21 @@
-"""jc - JSON CLI output utility ping Parser
+"""jc - JSON CLI output utility `ping` command output parser
 
-Usage:
+Supports `ping` and `ping6` output.
 
-    specify --ping as the first argument if the piped input is coming from ping
+Usage (cli):
 
-    Note:  Use the ping -c (count) option, otherwise data will not be piped to jc.
+    Note:  Use the ping `-c` (count) option, otherwise data will not be piped to `jc`.
+    
+    $ ping -c 3 1.2.3.4 | jc --ping
+
+    or
+
+    $ jc ping -c 3 1.2.3.4
+
+Usage (module):
+
+    import jc.parsers.ping
+    result = jc.parsers.ping.parse(ping_command_output)
 
 Compatibility:
 
