@@ -1,8 +1,17 @@
-"""jc - JSON CLI output utility pip-list Parser
+"""jc - JSON CLI output utility `pip-list` command output parser
 
-Usage:
+Usage (cli):
 
-    specify --pip-list as the first argument if the piped input is coming from pip list
+    $ pip list | jc --pip-list
+
+    or
+
+    $ jc pip list
+
+Usage (module):
+
+    import jc.parsers.pip_list
+    result = jc.parsers.pip_list.parse(pip_list_command_output)
 
 Compatibility:
 
