@@ -1,8 +1,17 @@
-"""jc - JSON CLI output utility pip-show Parser
+"""jc - JSON CLI output utility `pip-show` command output parser
 
-Usage:
+Usage (cli):
 
-    specify --pip-show as the first argument if the piped input is coming from pip show
+    $ pip show | jc --pip-show
+
+    or
+
+    $ jc pip show
+
+Usage (module):
+
+    import jc.parsers.pip_show
+    result = jc.parsers.pip_show.parse(pip_show_command_output)
 
 Compatibility:
 
