@@ -1,12 +1,21 @@
-"""jc - JSON CLI output utility ps Parser
+"""jc - JSON CLI output utility `ps` command output parser
 
-Usage:
+`ps` options supported:
+- `ef`
+- `axu`
 
-    specify --ps as the first argument if the piped input is coming from ps
+Usage (cli):
 
-    ps options supported:
-    - ef
-    - axu
+    $ ps | jc --ps
+
+    or
+
+    $ jc ps
+
+Usage (module):
+
+    import jc.parsers.ps
+    result = jc.parsers.ps.parse(ps_command_output)
 
 Compatibility:
 
