@@ -1,8 +1,17 @@
-"""jc - JSON CLI output utility route Parser
+"""jc - JSON CLI output utility `route` command output parser
 
-Usage:
+Usage (cli):
 
-    specify --route as the first argument if the piped input is coming from route
+    $ route | jc --route
+
+    or
+
+    $ jc route
+
+Usage (module):
+
+    import jc.parsers.route
+    result = jc.parsers.route.parse(route_command_output)
 
 Compatibility:
 
