@@ -1,8 +1,13 @@
-"""jc - JSON CLI output utility /etc/shadow file Parser
+"""jc - JSON CLI output utility `/etc/shadow` file parser
 
-Usage:
+Usage (cli):
 
-    specify --shadow as the first argument if the piped input is coming from /etc/shadow
+    $ sudo cat /etc/shadow | jc --shadow
+
+Usage (module):
+
+    import jc.parsers.shadow
+    result = jc.parsers.shadow.parse(shadow_file_output)
 
 Compatibility:
 
