@@ -1,8 +1,17 @@
-"""jc - JSON CLI output utility ss Parser
+"""jc - JSON CLI output utility `ss` command output parser
 
-Usage:
+Usage (cli):
 
-    specify --ss as the first argument if the piped input is coming from ss
+    $ ss | jc --ss
+
+    or
+
+    $ jc ss
+
+Usage (module):
+
+    import jc.parsers.ss
+    result = jc.parsers.ss.parse(ss_command_output)
 
 Limitations:
 
