@@ -1,8 +1,17 @@
-"""jc - JSON CLI output utility stat Parser
+"""jc - JSON CLI output utility `stat` command output parser
 
-Usage:
+Usage (cli):
 
-    specify --stat as the first argument if the piped input is coming from stat
+    $ stat * | jc --stat
+
+    or
+
+    $ jc stat *
+
+Usage (module):
+
+    import jc.parsers.stat
+    result = jc.parsers.stat.parse(stat_command_output)
 
 Compatibility:
 
