@@ -1,12 +1,19 @@
-"""jc - JSON CLI output utility sysctl -a Parser
+"""jc - JSON CLI output utility `sysctl -a` command output parser
 
-Usage:
+Note: Since `sysctl` output is not easily parsable only a very simple key/value object will be output. An attempt is made to convert obvious integers and floats. If no conversion is desired, use the `-r` command-line argument or the `raw=True` argument in `parse()`.
 
-    specify --sysctl as the first argument if the piped input is coming from sysctl -a
+Usage (cli):
 
-    Note: since sysctl output is not easily parsable only a very simple key/value object
-          will be output. An attempt is made to convert obvious integers and floats. If no
-          conversion is desired, use the -r (raw) option.
+    $ sysctl -a | jc --sysctl
+
+    or
+
+    $ jc sysctl -a
+
+Usage (module):
+
+    import jc.parsers.sysctl
+    result = jc.parsers.sysctl.parse(sysctl_command_output)
 
 Compatibility:
 
@@ -14,7 +21,7 @@ Compatibility:
 
 Examples:
 
-    $ sysctl | jc --sysctl -p
+    $ sysctl -a | jc --sysctl -p
     {
       "user.cs_path": "/usr/bin:/bin:/usr/sbin:/sbin",
       "user.bc_base_max": 99,
@@ -26,7 +33,7 @@ Examples:
       ...
     }
 
-    $ sysctl | jc --sysctl -p -r
+    $ sysctl -a | jc --sysctl -p -r
     {
       "user.cs_path": "/usr/bin:/bin:/usr/sbin:/sbin",
       "user.bc_base_max": "99",
