@@ -1,8 +1,17 @@
-"""jc - JSON CLI output utility systemctl-lj Parser
+"""jc - JSON CLI output utility `systemctl list-jobs` command output parser
 
-Usage:
+Usage (cli):
 
-    specify --systemctl-lj as the first argument if the piped input is coming from systemctl list-jobs
+    $ systemctl list-jobs | jc --systemctl-lj
+
+    or
+
+    $ jc systemctl list-jobs
+
+Usage (module):
+
+    import jc.parsers.systemctl_lj
+    result = jc.parsers.systemctl_lj.parse(systemctl_lj_command_output)
 
 Compatibility:
 
