@@ -1,8 +1,17 @@
-"""jc - JSON CLI output utility timedatectl Parser
+"""jc - JSON CLI output utility `timedatectl` command output parser
 
-Usage:
+Usage (cli):
 
-    specify --timedatectl as the first argument if the piped input is coming from timedatectl or timedatectl status
+    $ timedatectl | jc --timedatectl
+
+    or
+
+    $ jc timedatectl
+
+Usage (module):
+
+    import jc.parsers.timedatectl
+    result = jc.parsers.timedatectl.parse(timedatectl_command_output)
 
 Compatibility:
 
