@@ -1,14 +1,23 @@
-"""jc - JSON CLI output utility traceroute Parser
+"""jc - JSON CLI output utility `traceroute` command output parser
 
-Usage:
+Supports `traceroute` and `traceroute6` output.
 
-    specify --traceroute as the first argument if the piped input is coming from traceroute
+Note: On some operating systems you will need to redirect `STDERR` to `STDOUT` for destination info since the header line is sent to `STDERR`. A warning message will be printed to `STDERR` if the header row is not found.
 
-    Note: On some operating systems you will need to redirect STDERR to STDOUT for destination
-          info since the header line is sent to STDERR. A warning message will be printed to
-          STDERR if the header row is not found.
+e.g. `$ traceroute 8.8.8.8 2>&1 | jc --traceroute`
 
-          e.g. $ traceroute 8.8.8.8 2>&1 | jc --traceroute
+Usage (cli):
+
+    $ traceroute 1.2.3.4 | jc --traceroute
+
+    or
+
+    $ jc traceroute 1.2.3.4
+
+Usage (module):
+
+    import jc.parsers.traceroute
+    result = jc.parsers.traceroute.parse(traceroute_command_output)
 
 Compatibility:
 
