@@ -1,12 +1,19 @@
-"""jc - JSON CLI output utility uname Parser
+"""jc - JSON CLI output utility `uname -a` command output parser
 
-Usage:
+Note: Must use `uname -a`
 
-    specify --uname as the first argument if the piped input is coming from uname
+Usage (cli):
 
-Limitations:
+    $ uname -a | jc --uname
 
-    must use 'uname -a'
+    or
+
+    $ jc uname -a
+
+Usage (module):
+
+    import jc.parsers.uname
+    result = jc.parsers.uname.parse(uname_command_output)
 
 Compatibility:
 
