@@ -1,8 +1,17 @@
-"""jc - JSON CLI output utility uptime Parser
+"""jc - JSON CLI output utility `uptime` command output parser
 
-Usage:
+Usage (cli):
 
-    specify --uptime as the first argument if the piped input is coming from uptime
+    $ uptime | jc --uptime
+
+    or
+
+    $ jc uptime
+
+Usage (module):
+
+    import jc.parsers.uptime
+    result = jc.parsers.uptime.parse(uptime_command_output)
 
 Compatibility:
 
