@@ -1,10 +1,19 @@
-"""jc - JSON CLI output utility who Parser
+"""jc - JSON CLI output utility `who` command output parser
 
-Usage:
+Accepts any of the following who options (or no options): `-aTH`
 
-    specify --who as the first argument if the piped input is coming from who
+Usage (cli):
 
-    accepts any of the following who options (or no options): -aTH
+    $ who | jc --who
+
+    or
+
+    $ jc who
+
+Usage (module):
+
+    import jc.parsers.who
+    result = jc.parsers.who.parse(who_command_output)
 
 Compatibility:
 
