@@ -1,8 +1,13 @@
-"""jc - JSON CLI output utility YAML Parser
+"""jc - JSON CLI output utility `YAML` file parser
 
-Usage:
+Usage (cli):
 
-    specify --yaml as the first argument if the piped input is coming from a YAML file
+    $ cat foo.yaml | jc --yaml
+
+Usage (module):
+
+    import jc.parsers.yaml
+    result = jc.parsers.yaml.parse(yaml_file_output)
 
 Compatibility:
 
